@@ -100,6 +100,13 @@ sub error_cb { shift->_add_event('error', @_) }
 sub finish {
     my ($self, $id) = @_;
 
+    # Connections
+    my $c = $self->_connections;
+
+    # Finish connection now
+    $self->drop($id) and return $self
+      if !$c->{$id}->{buffer} || !$c->{$id}->{buffer}->size;
+
     # Finish connection once buffer is empty
     $self->_connections->{$id}->{finish} = 1;
 
@@ -334,8 +341,7 @@ sub _prepare {
         $self->drop($id)
           and next
           if $c->{$id}->{finish}
-              && $c->{$id}->{buffer}
-              && !$c->{$id}->{buffer}->size;
+              && (!$c->{$id}->{buffer} || !$c->{$id}->{buffer}->size);
 
         # Read only
         $self->not_writing($id) if delete $c->{$id}->{read_only};
